summaryrefslogtreecommitdiff
path: root/src/lib/video_content.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-03-17 00:22:52 +0000
committerCarl Hetherington <cth@carlh.net>2014-03-17 00:22:52 +0000
commit2e504b33eb9f38cac629ad31b7c107fb0cf5efda (patch)
tree9c571653f312597b744896d45e27d422acbeea88 /src/lib/video_content.cc
parenta4c19a34244aeaf183c25878933b570fc5c0ee34 (diff)
parent48b2c7b8ec57e72f2f27d5080e54e4b3c3fcda3d (diff)
Merge master.
Diffstat (limited to 'src/lib/video_content.cc')
-rw-r--r--src/lib/video_content.cc23
1 files changed, 17 insertions, 6 deletions
diff --git a/src/lib/video_content.cc b/src/lib/video_content.cc
index 11310c5da..c3aea2b0f 100644
--- a/src/lib/video_content.cc
+++ b/src/lib/video_content.cc
@@ -442,19 +442,30 @@ VideoContentScale::name () const
return _("No scale");
}
+/** @param display_container Size of the container that we are displaying this content in.
+ * @param film_container The size of the film's image.
+ */
dcp::Size
-VideoContentScale::size (shared_ptr<const VideoContent> c, dcp::Size container) const
+VideoContentScale::size (shared_ptr<const VideoContent> c, dcp::Size display_container, dcp::Size film_container) const
{
if (_ratio) {
- return fit_ratio_within (_ratio->ratio (), container);
+ return fit_ratio_within (_ratio->ratio (), display_container);
}
- /* Force scale if the container is smaller than the content's image */
- if (_scale || container.width < c->video_size().width || container.height < c->video_size().height) {
- return fit_ratio_within (c->video_size().ratio (), container);
+ libdcp::Size const ac = c->video_size_after_crop ();
+
+ /* Force scale if the film_container is smaller than the content's image */
+ if (_scale || film_container.width < ac.width || film_container.height < ac.height) {
+ return fit_ratio_within (ac.ratio (), display_container);
}
- return c->video_size ();
+ /* Scale the image so that it will be in the right place in film_container, even if display_container is a
+ different size.
+ */
+ return libdcp::Size (
+ c->video_size().width * float(display_container.width) / film_container.width,
+ c->video_size().height * float(display_container.height) / film_container.height
+ );
}
void